@@ -1,6 +1,6 @@
 ;;; org-capture.el --- Fast note taking in Org       -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2010-2018 Free Software Foundation, Inc.
+;; Copyright (C) 2010-2019 Free Software Foundation, Inc.
 
 ;; Author: Carsten Dominik <carsten at orgmode dot org>
 ;; Keywords: outlines, hypermedia, calendar, wp
@@ -1333,8 +1333,7 @@ may have been stored before."
 	(org-capture-narrow beg (1- end))
 	(when (or (search-backward "%?" beg t)
 		  (search-forward "%?" end t))
-	  (replace-match "")))
-      (org-table-align))))
+	  (replace-match ""))))))
 
 (defun org-capture-place-plain-text ()
   "Place the template plainly.
